@@ -1,11 +1,14 @@
 use std::sync::Arc;
 
+use camino::Utf8PathBuf;
+
 use crate::analyse::TargetSupport;
 use crate::build::Target;
 use crate::config::PackageConfig;
 use crate::line_numbers::LineNumbers;
 use crate::type_::expression::FunctionDefinition;
 use crate::type_::{Deprecation, PRELUDE_MODULE_NAME};
+use crate::warning::WarningEmitter;
 use crate::{
     ast::{SrcSpan, TypedExpr},
     build::Located,
@@ -21,7 +24,9 @@ use super::{Publicity, Statement, TypedModule, TypedStatement};
 
 fn compile_module(src: &str) -> TypedModule {
     use crate::type_::build_prelude;
-    let parsed = crate::parse::parse_module(src).expect("syntax error");
+    let parsed =
+        crate::parse::parse_module(Utf8PathBuf::from("test/path"), src, &WarningEmitter::null())
+            .expect("syntax error");
     let ast = parsed.module;
     let ids = UniqueIdGenerator::new();
     let mut config = PackageConfig::default();
@@ -146,7 +151,6 @@ fn compile_expression(src: &str) -> TypedStatement {
         errors,
     )
     .infer_statements(ast)
-    .expect("should successfully infer")
     .first()
     .clone()
 }
