@@ -56,7 +56,7 @@ fn tuple_with_last_splittable_arg() {
 #[test]
 fn constant_long_list_of_tuples() {
     assert_format!(
-        r#"const foo = [
+        r#"const wibble = [
   #(1, 2), #(3, 4), #(5, 6), #(7, 8), #(9, 10), #(11, 12), #(1, 2), #(3, 4),
   #(5, 6), #(7, 8), #(9, 10), #(11, 12),
 ]
