@@ -202,6 +202,10 @@ impl<'module> Generator<'module> {
             TypedExpr::NegateBool { value, .. } => self.negate_with("!", value),
 
             TypedExpr::NegateInt { value, .. } => self.negate_with("- ", value),
+
+            TypedExpr::Invalid { .. } => {
+                panic!("invalid expressions should not reach code generation")
+            }
         }?;
         Ok(if expression.handles_own_return() {
             document
@@ -228,6 +232,20 @@ impl<'module> Generator<'module> {
 
                 // Sized ints
                 [Opt::Size { value: size, .. }] => {
+                    let size_int = match *size.clone() {
+                        TypedExpr::Int {
+                            location: _,
+                            typ: _,
+                            value,
+                        } => value.parse().unwrap_or(0),
+                        _ => 0,
+                    };
+                    if size_int > 0 && size_int % 8 != 0 {
+                        return Err(Error::Unsupported {
+                            feature: "Non byte aligned array".into(),
+                            location: segment.location,
+                        });
+                    }
                     self.tracker.sized_integer_segment_used = true;
                     let size = self.not_in_tail_position(|gen| gen.wrap_expression(size))?;
                     Ok(docvec!["sizedInt(", value, ", ", size, ")"])
@@ -372,7 +390,7 @@ impl<'module> Generator<'module> {
     ) -> Output<'a> {
         match &constructor.variant {
             ValueConstructorVariant::LocalConstant { literal } => {
-                constant_expression(self.tracker, literal)
+                constant_expression(Context::Function, self.tracker, literal)
             }
             ValueConstructorVariant::Record { arity, .. } => {
                 Ok(self.record_constructor(constructor.type_.clone(), None, name, *arity))
@@ -1232,11 +1250,24 @@ pub(crate) fn guard_constant_expression<'a>(
             .map(|assignment| assignment.subject.clone().append(assignment.path.clone()))
             .unwrap_or_else(|| maybe_escape_identifier_doc(name))),
 
-        expression => constant_expression(tracker, expression),
+        expression => constant_expression(Context::Function, tracker, expression),
     }
 }
 
+#[derive(Debug, Clone, Copy)]
+/// The context where the constant expression is used, it might be inside a
+/// function call, or in the definition of another constant.
+///
+/// Based on the context we might want to annotate pure function calls as
+/// "@__PURE__".
+///
+pub enum Context {
+    Constant,
+    Function,
+}
+
 pub(crate) fn constant_expression<'a>(
+    context: Context,
     tracker: &mut UsageTracker,
     expression: &'a TypedConstant,
 ) -> Output<'a> {
@@ -1244,13 +1275,24 @@ pub(crate) fn constant_expression<'a>(
         Constant::Int { value, .. } => Ok(int(value)),
         Constant::Float { value, .. } => Ok(float(value)),
         Constant::String { value, .. } => Ok(string(value)),
-        Constant::Tuple { elements, .. } => {
-            array(elements.iter().map(|e| constant_expression(tracker, e)))
-        }
+        Constant::Tuple { elements, .. } => array(
+            elements
+                .iter()
+                .map(|e| constant_expression(context, tracker, e)),
+        ),
 
         Constant::List { elements, .. } => {
             tracker.list_used = true;
-            list(elements.iter().map(|e| constant_expression(tracker, e)))
+            let list = list(
+                elements
+                    .iter()
+                    .map(|e| constant_expression(context, tracker, e)),
+            )?;
+
+            match context {
+                Context::Constant => Ok(docvec!["/* @__PURE__ */ ", list]),
+                Context::Function => Ok(list),
+            }
         }
 
         Constant::Record { typ, name, .. } if typ.is_bool() && name == "True" => {
@@ -1262,10 +1304,11 @@ pub(crate) fn constant_expression<'a>(
         Constant::Record { typ, .. } if typ.is_nil() => Ok("undefined".to_doc()),
 
         Constant::Record {
-            tag,
-            typ,
             args,
             module,
+            name,
+            tag,
+            typ,
             ..
         } => {
             if typ.is_result() {
@@ -1277,12 +1320,25 @@ pub(crate) fn constant_expression<'a>(
             }
             let field_values: Vec<_> = args
                 .iter()
-                .map(|arg| constant_expression(tracker, &arg.value))
+                .map(|arg| constant_expression(context, tracker, &arg.value))
                 .try_collect()?;
-            Ok(construct_record(module.as_deref(), tag, field_values))
+
+            let constructor = construct_record(module.as_deref(), name, field_values);
+            match context {
+                Context::Constant => Ok(docvec!["/* @__PURE__ */ ", constructor]),
+                Context::Function => Ok(constructor),
+            }
         }
 
-        Constant::BitArray { segments, .. } => bit_array(tracker, segments, constant_expression),
+        Constant::BitArray { segments, .. } => {
+            let bit_array = bit_array(tracker, segments, |tracker, expr| {
+                constant_expression(context, tracker, expr)
+            })?;
+            match context {
+                Context::Constant => Ok(docvec!["/* @__PURE__ */ ", bit_array]),
+                Context::Function => Ok(bit_array),
+            }
+        }
 
         Constant::Var { name, module, .. } => Ok({
             match module {
@@ -1317,6 +1373,16 @@ fn bit_array<'a>(
 
             // Sized ints
             [Opt::Size { value: size, .. }] => {
+                let size_int = match *size.clone() {
+                    Constant::Int { location: _, value } => value.parse().unwrap_or(0),
+                    _ => 0,
+                };
+                if size_int > 0 && size_int % 8 != 0 {
+                    return Err(Error::Unsupported {
+                        feature: "Non byte aligned array".into(),
+                        location: segment.location,
+                    });
+                }
                 tracker.sized_integer_segment_used = true;
                 let size = constant_expr_fun(tracker, size)?;
                 Ok(docvec!["sizedInt(", value, ", ", size, ")"])
@@ -1463,7 +1529,8 @@ impl TypedExpr {
             | TypedExpr::BitArray { .. }
             | TypedExpr::RecordUpdate { .. }
             | TypedExpr::NegateBool { .. }
-            | TypedExpr::NegateInt { .. } => false,
+            | TypedExpr::NegateInt { .. }
+            | TypedExpr::Invalid { .. } => false,
         }
     }
 }
@@ -1527,7 +1594,8 @@ fn requires_semicolon(statement: &TypedStatement) -> bool {
             TypedExpr::Todo { .. }
             | TypedExpr::Case { .. }
             | TypedExpr::Panic { .. }
-            | TypedExpr::Pipeline { .. },
+            | TypedExpr::Pipeline { .. }
+            | TypedExpr::Invalid { .. },
         ) => false,
 
         Statement::Assignment(_) => false,
