@@ -1,7 +1,9 @@
 use self::expression::CallKind;
 
 use super::*;
-use crate::ast::{Assignment, AssignmentKind, TypedAssignment, UntypedExpr, PIPE_VARIABLE};
+use crate::ast::{
+    Assignment, AssignmentKind, Statement, TypedAssignment, UntypedExpr, PIPE_VARIABLE,
+};
 use vec1::Vec1;
 
 #[derive(Debug)]
@@ -33,12 +35,7 @@ impl<'a, 'b, 'c> PipeTyper<'a, 'b, 'c> {
         expressions: Vec1<UntypedExpr>,
     ) -> Result<TypedExpr, Error> {
         let size = expressions.len();
-        let end = &expressions[..]
-            .last()
-            // The vec is non-empty, this indexing can never fail
-            .expect("Empty pipeline in typer")
-            .location()
-            .end;
+        let end = expressions.last().location().end;
         let mut expressions = expressions.into_iter();
         let first = expr_typer.infer(expressions.next().expect("Empty pipeline in typer"))?;
         let mut typer = Self {
@@ -48,7 +45,7 @@ impl<'a, 'b, 'c> PipeTyper<'a, 'b, 'c> {
             argument_location: first.location(),
             location: SrcSpan {
                 start: first.location().start,
-                end: *end,
+                end,
             },
             assignments: Vec::with_capacity(size),
         };
@@ -90,6 +87,8 @@ impl<'a, 'b, 'c> PipeTyper<'a, 'b, 'c> {
                     .warn_for_unreachable_code(call.location(), PanicPosition::PreviousExpression);
             }
 
+            self.warn_if_call_first_argument_is_hole(&call);
+
             let call = match call {
                 // left |> right(..args)
                 UntypedExpr::Call {
@@ -120,6 +119,7 @@ impl<'a, 'b, 'c> PipeTyper<'a, 'b, 'c> {
                 self.push_assignment(call);
             }
         }
+
         Ok(finally.expect("Empty pipeline in typer"))
     }
 
@@ -316,4 +316,26 @@ impl<'a, 'b, 'c> PipeTyper<'a, 'b, 'c> {
             _ => false,
         }
     }
+
+    fn warn_if_call_first_argument_is_hole(&mut self, call: &UntypedExpr) {
+        if let UntypedExpr::Fn {
+            is_capture: true,
+            body,
+            ..
+        } = &call
+        {
+            if let Statement::Expression(UntypedExpr::Call { arguments, .. }) = body.first() {
+                match arguments.as_slice() {
+                    [first] | [first, ..] if first.is_capture_hole() => {
+                        self.expr_typer.environment.warnings.emit(
+                            Warning::RedundantPipeFunctionCapture {
+                                location: first.location,
+                            },
+                        )
+                    }
+                    _ => (),
+                }
+            }
+        }
+    }
 }
